==> haskell-pretty-simple-4.1.2.0-102-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pretty-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pretty-simple
version:              4.1.2.0
visibility:           public
id:                   pretty-simple-4.1.2.0-Ke1UaCL4XIu3y9zB3GGfu
key:                  pretty-simple-4.1.2.0-Ke1UaCL4XIu3y9zB3GGfu
license:              BSD-3-Clause
copyright:            2017-2019 Dennis Gosnell
maintainer:           cdep.illabout@gmail.com
author:               Dennis Gosnell
homepage:             https://github.com/cdepillabout/pretty-simple
synopsis:             pretty printer for data types with a '\''Show'\'' instance.
description:
    Please see <https://github.com/cdepillabout/pretty-simple#readme README.md>.

category:             Text
abi:                  88da4bec034add632b91305691e8e49b
exposed:              True
exposed-modules:
    Debug.Pretty.Simple Text.Pretty.Simple Text.Pretty.Simple.Internal
    Text.Pretty.Simple.Internal.Color Text.Pretty.Simple.Internal.Expr
    Text.Pretty.Simple.Internal.ExprParser
    Text.Pretty.Simple.Internal.Printer

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pretty-simple-4.1.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pretty-simple-4.1.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pretty-simple-4.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pretty-simple
hs-libraries:         HSpretty-simple-4.1.2.0-Ke1UaCL4XIu3y9zB3GGfu
depends:
    base-4.17.2.1 containers-0.6.7 mtl-2.2.2
    prettyprinter-1.7.1-6jCWnP5jsaKCzg7tcQDjYG
    prettyprinter-ansi-terminal-1.1.3-E63Ye1CuDmE7S322wUrIHt text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-pretty-simple/html/pretty-simple.haddock

haddock-html:         /usr/share/doc/haskell-pretty-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pretty-simple-4.1.2.0-103-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pretty-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pretty-simple
version:              4.1.2.0
visibility:           public
id:                   pretty-simple-4.1.2.0-2z70eQKfzMZKNEwY8jEM3v
key:                  pretty-simple-4.1.2.0-2z70eQKfzMZKNEwY8jEM3v
license:              BSD-3-Clause
copyright:            2017-2019 Dennis Gosnell
maintainer:           cdep.illabout@gmail.com
author:               Dennis Gosnell
homepage:             https://github.com/cdepillabout/pretty-simple
synopsis:             pretty printer for data types with a '\''Show'\'' instance.
description:
    Please see <https://github.com/cdepillabout/pretty-simple#readme README.md>.

category:             Text
abi:                  4db795a0284a8ca098d6c0c0032bc368
exposed:              True
exposed-modules:
    Debug.Pretty.Simple Text.Pretty.Simple Text.Pretty.Simple.Internal
    Text.Pretty.Simple.Internal.Color Text.Pretty.Simple.Internal.Expr
    Text.Pretty.Simple.Internal.ExprParser
    Text.Pretty.Simple.Internal.Printer

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pretty-simple-4.1.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pretty-simple-4.1.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pretty-simple-4.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pretty-simple
hs-libraries:         HSpretty-simple-4.1.2.0-2z70eQKfzMZKNEwY8jEM3v
depends:
    base-4.17.2.1 containers-0.6.7 mtl-2.2.2
    prettyprinter-1.7.1-AXDleNapq6SGrYeQXJmaAE
    prettyprinter-ansi-terminal-1.1.3-Db20N542Y0L5jpnidIh2tm text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-pretty-simple/html/pretty-simple.haddock

haddock-html:         /usr/share/doc/haskell-pretty-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
